# -*- coding: utf-8 -*-
# -----------------------------------
# @CreateTime   : 2020/3/10 1:46
# @Author       : Mark Shawn
# @Email        : shawninjuly@gmai.com
# ------------------------------------
from myimage.upload import qiniuyun, sm_ms

upload_img = sm_ms.SMMS().upload_img

IMG_SMMS = sm_ms.SMMS
IMG_Qiniuyun = qiniuyun.Qiniuyun




# -*- coding: utf-8 -*-
# -----------------------------------
# @CreateTime   : 2020/3/10 3:59
# @Author       : Mark Shawn
# @Email        : shawninjuly@gmai.com
# ------------------------------------

# 若从文件加载，七牛云的设置如下
# 详情可以参见官网：https://developer.qiniu.com/kodo/sdk/1242/python
QINIU_DOMAIN = ''
QINIU_BUCKET = ''
QINIU_AK     = ''
QINIU_SK     = ''


# -*- coding: utf-8 -*-
# -----------------------------------
# @CreateTime   : 2020/3/10 1:47
# @Author       : Mark Shawn
# @Email        : shawninjuly@gmai.com
# ------------------------------------
import qiniu

from myimage.common import *
from myimage import settings as st


class Qiniuyun:

	def __init__(self):
		self._must_keys = [
			"QINIU_DOMAIN",
			"QINIU_BUCKET",
			"QINIU_AK",
			"QINIU_SK"
		]
		try:
			self.init_from_settings()
		except NotImplementedError:
			logging.warning("建议通过settings文件配置七牛云，否则必须通过`self.init_from_params`初始化！")


	def init_from_settings(self):
		for key in self._must_keys:
			if not hasattr(st, key):
				raise NotImplementedError("从`upload/settings.py`文件初始化七牛云，必须要有以下键：{}".format(self._must_keys))
			else:
				setattr(self, key, getattr(st, key))
		self.q = qiniu.Auth(self.__ak, self.__sk)

	def init_from_params(self, domain, bucket, ak, sk):
		self._domain = domain
		self._bucket = bucket
		self.__ak    = ak
		self.__sk    = sk
		self.q = qiniu.Auth(self.__ak, self.__sk)

	@check_local_exist
	def upload_img(self, img_path: str, check_exist=True):
		"""
		上传文件到七牛云与个人站点

		:param img_path: 要上传的本地文件地址
		:param check_exist: 是否检查目标服务器已存在对应文件，如果有，则不上传
		:return: 目标图像的外链
		"""
		key = os.path.basename(img_path)
		img_path_online =  "{}/{}".format(self._domain, key)
		if check_exist and check_target_exist(img_path_online):
			logging.info("Using cached: {}".format(img_path_online))
		else:
			token = self.q.upload_token(self._bucket, key, 3600)
			ret, info = qiniu.put_file(token , key, img_path)
			assert ret["key"] == key
			logging.info("Uploaded: {}".format(img_path_online))
		return img_path_online


if __name__ == '__main__':
	q = Qiniuyun()
	q.init_from_settings()



# -*- coding: utf-8 -*-
# -----------------------------------
# @CreateTime   : 2020/3/10 3:41
# @Author       : Mark Shawn
# @Email        : shawninjuly@gmai.com
# ------------------------------------
from myimage.common import *


class SMMS:

	def __init__(self):
		self._host = 'https://sm.ms/api/v2'
		self._upload_api = self._host + '/upload'

	@check_local_exist
	def upload_img(self, img_path):
		result = requests.post(self._upload_api, files={"smfile": open(img_path, "rb")}).json()
		if result["code"] == "success":
			logging.info("Uploaded {}".format(result["data"]["url"]))
			return result['data']["url"]

		elif result["code"] == "image_repeated":
			logging.info("Repeated {}".format(result["images"]))
			return result["images"]

		else:
			raise Exception(result)


if __name__ == '__main__':
	SMMS().upload_img(r'C:\Users\mark\Documents\微信截图_20190806164931.png')


# -*- coding: utf-8 -*-
# -----------------------------------
# @CreateTime   : 2020/3/10 1:48
# @Author       : Mark Shawn
# @Email        : shawninjuly@gmai.com
# ------------------------------------
import logging
logging.basicConfig(level=logging.INFO, format="%(asctime)s %(levelname)s: %(message)s")

import os
import requests


def check_local_exist(func):
	def wrapper(self, img_path, *args, **kwargs):
		assert os.path.exists(img_path), "本地不存在该图片！请核实: {}".format(img_path)
		return func(self, img_path, *args, **kwargs)
	return wrapper


def check_target_exist(target_path: str):
	return requests.head(target_path).status_code == 200


# -*- coding: utf-8 -*-
# -----------------------------------
# @CreateTime   : 2020/3/10 3:59
# @Author       : Mark Shawn
# @Email        : shawninjuly@gmai.com
# ------------------------------------

QINIU_DOMAIN = 'img.nanchuan.site'
QINIU_BUCKET = "pfa"
QINIU_AK     = 'Li-8HoZaqUHFzZ8l87WL-JzBRpjK7c1HTFgSoWso'
QINIU_SK     = '_Y_ywcqqrmpDskjCrpH2A35iOQMjMHdIsdTsTbz0'



# -*- coding: utf-8 -*-
# -----------------------------------
# @CreateTime   : 2020/3/10 2:14
# @Author       : Mark Shawn
# @Email        : shawninjuly@gmai.com
# ------------------------------------

import setuptools

with open("README.md", "r", encoding="utf-8") as fh:
    long_description = fh.read()

setuptools.setup(
    name="myimage", # Replace with your own username
    version="0.0.5",
    author="MarkShawn",
    author_email="shawninjuly@gmail.com",
    description="A handful module for uploading local image and then get the path from specific server, "
                "especially good for those writing markdown journals.",
    long_description=long_description,
    long_description_content_type="text/markdown",
    url="https://github.com/MarkShawn2020/myimage",
    packages=setuptools.find_packages(
        exclude=['*.settings', ]),
    classifiers=[
        "Programming Language :: Python :: 3",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent",
    ],
    python_requires='>=3.5',
    install_requires=[
        "requests",
        "qiniu",
    ],
)